@@ -17,7 +17,6 @@
 package org.apache.catalina.ha.deploy;
 
 import java.io.File;
-import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.util.HashMap;
 
@@ -62,7 +61,7 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
     /*--Instance Variables--------------------------------------*/
     protected boolean started = false;
 
-    protected final HashMap<String,FileMessageFactory> fileFactories = new HashMap<>();
+    protected final HashMap<String, FileMessageFactory> fileFactories = new HashMap<>();
 
     /**
      * Deployment directory.
@@ -146,7 +145,8 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
             return;
         }
         Engine engine = (Engine) econtainer;
-        String hostname = host.getName();
+        String hostname = null;
+        hostname = host.getName();
         try {
             oname = new ObjectName(engine.getName() + ":type=Deployer,host=" + hostname);
         } catch (Exception e) {
@@ -163,7 +163,7 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
         configBase = host.getConfigBaseFile();
 
         // Retrieve the MBean server
-        mBeanServer = Registry.getRegistry(null).getMBeanServer();
+        mBeanServer = Registry.getRegistry(null, null).getMBeanServer();
 
         started = true;
         count = 0;
@@ -206,8 +206,8 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
         try {
             if (msg instanceof FileMessage) {
                 FileMessage fmsg = (FileMessage) msg;
-                if (log.isTraceEnabled()) {
-                    log.trace(sm.getString("farmWarDeployer.msgRxDeploy", fmsg.getContextName(), fmsg.getFileName()));
+                if (log.isDebugEnabled()) {
+                    log.debug(sm.getString("farmWarDeployer.msgRxDeploy", fmsg.getContextName(), fmsg.getFileName()));
                 }
                 FileMessageFactory factory = getFactory(fmsg);
                 // TODO correct second try after app is in service!
@@ -231,14 +231,14 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
                                 removeServiced(contextName);
                             }
                             check(contextName);
-                            if (log.isTraceEnabled()) {
-                                log.trace(sm.getString("farmWarDeployer.deployEnd", contextName));
+                            if (log.isDebugEnabled()) {
+                                log.debug(sm.getString("farmWarDeployer.deployEnd", contextName));
                             }
                         } else {
                             log.error(sm.getString("farmWarDeployer.servicingDeploy", contextName, name));
                         }
-                    } catch (Exception e) {
-                        log.error(sm.getString("farmWarDeployer.fileMessageError"), e);
+                    } catch (Exception ex) {
+                        log.error(sm.getString("farmWarDeployer.fileMessageError"), ex);
                     } finally {
                         removeFactory(fmsg);
                     }
@@ -247,8 +247,8 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
                 try {
                     UndeployMessage umsg = (UndeployMessage) msg;
                     String contextName = umsg.getContextName();
-                    if (log.isTraceEnabled()) {
-                        log.trace(sm.getString("farmWarDeployer.msgRxUndeploy", contextName));
+                    if (log.isDebugEnabled()) {
+                        log.debug(sm.getString("farmWarDeployer.msgRxUndeploy", contextName));
                     }
                     if (tryAddServiced(contextName)) {
                         try {
@@ -256,18 +256,18 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
                         } finally {
                             removeServiced(contextName);
                         }
-                        if (log.isTraceEnabled()) {
-                            log.trace(sm.getString("farmWarDeployer.undeployEnd", contextName));
+                        if (log.isDebugEnabled()) {
+                            log.debug(sm.getString("farmWarDeployer.undeployEnd", contextName));
                         }
                     } else {
                         log.error(sm.getString("farmWarDeployer.servicingUndeploy", contextName));
                     }
-                } catch (Exception e) {
-                    log.error(sm.getString("farmWarDeployer.undeployMessageError"), e);
+                } catch (Exception ex) {
+                    log.error(sm.getString("farmWarDeployer.undeployMessageError"), ex);
                 }
             }
-        } catch (IOException ioe) {
-            log.error(sm.getString("farmWarDeployer.msgIoe"), ioe);
+        } catch (java.io.IOException x) {
+            log.error(sm.getString("farmWarDeployer.msgIoe"), x);
         }
     }
 
@@ -278,10 +278,11 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
      *
      * @return Factory for all app message (war files)
      *
-     * @throws FileNotFoundException Missing file error
-     * @throws IOException           Other IO error
+     * @throws java.io.FileNotFoundException Missing file error
+     * @throws java.io.IOException           Other IO error
      */
-    public synchronized FileMessageFactory getFactory(FileMessage msg) throws FileNotFoundException, IOException {
+    public synchronized FileMessageFactory getFactory(FileMessage msg)
+            throws java.io.FileNotFoundException, java.io.IOException {
         File writeToFile = new File(getTempDirFile(), msg.getFileName());
         FileMessageFactory factory = fileFactories.get(msg.getFileName());
         if (factory == null) {
@@ -302,13 +303,17 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
     }
 
     /**
-     * {@inheritDoc}
-     * <p>
-     * This listener accepts only FileMessage or UndeployMessage.
+     * Before the cluster invokes messageReceived the cluster will ask the receiver to accept or decline the message, In
+     * the future, when messages get big, the accept method will only take a message header
+     *
+     * @param msg ClusterMessage
+     *
+     * @return boolean - returns true to indicate that messageReceived should be invoked. If false is returned, the
+     *             messageReceived method will not be invoked.
      */
     @Override
     public boolean accept(ClusterMessage msg) {
-        return msg instanceof FileMessage || msg instanceof UndeployMessage;
+        return (msg instanceof FileMessage) || (msg instanceof UndeployMessage);
     }
 
     /**
@@ -335,21 +340,21 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
         Member localMember = getCluster().getLocalMember();
         FileMessageFactory factory = FileMessageFactory.getInstance(webapp, false);
         FileMessage msg = new FileMessage(localMember, webapp.getName(), contextName);
-        if (log.isTraceEnabled()) {
-            log.trace(sm.getString("farmWarDeployer.sendStart", contextName, webapp));
+        if (log.isDebugEnabled()) {
+            log.debug(sm.getString("farmWarDeployer.sendStart", contextName, webapp));
         }
         msg = factory.readMessage(msg);
         while (msg != null) {
             for (Member member : members) {
-                if (log.isTraceEnabled()) {
-                    log.trace(sm.getString("farmWarDeployer.sendFragment", contextName, webapp, member));
+                if (log.isDebugEnabled()) {
+                    log.debug(sm.getString("farmWarDeployer.sendFragment", contextName, webapp, member));
                 }
                 getCluster().send(msg, member);
             }
             msg = factory.readMessage(msg);
         }
-        if (log.isTraceEnabled()) {
-            log.trace(sm.getString("farmWarDeployer.sendEnd", contextName, webapp));
+        if (log.isDebugEnabled()) {
+            log.debug(sm.getString("farmWarDeployer.sendEnd", contextName, webapp));
         }
     }
 
@@ -376,8 +381,8 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
             Member localMember = getCluster().getLocalMember();
             UndeployMessage msg = new UndeployMessage(localMember, System.currentTimeMillis(),
                     "Undeploy:" + contextName + ":" + System.currentTimeMillis(), contextName);
-            if (log.isTraceEnabled()) {
-                log.trace(sm.getString("farmWarDeployer.removeTxMsg", contextName));
+            if (log.isDebugEnabled()) {
+                log.debug(sm.getString("farmWarDeployer.removeTxMsg", contextName));
             }
             cluster.send(msg);
         }
@@ -395,13 +400,18 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
                     log.error(sm.getString("farmWarDeployer.removeFailRemote", contextName));
                 }
 
-            } catch (Exception e) {
-                log.error(sm.getString("farmWarDeployer.removeFailLocal", contextName), e);
+            } catch (Exception ex) {
+                log.error(sm.getString("farmWarDeployer.removeFailLocal", contextName), ex);
             }
         }
 
     }
 
+    /**
+     * Modification from watchDir war detected!
+     *
+     * @see org.apache.catalina.ha.deploy.FileChangeListener#fileModified(File)
+     */
     @Override
     public void fileModified(File newWar) {
         try {
@@ -428,11 +438,16 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
                 log.error(sm.getString("farmWarDeployer.servicingDeploy", cn.getName(), deployWar.getName()));
             }
             install(cn.getName(), deployWar);
-        } catch (Exception e) {
-            log.error(sm.getString("farmWarDeployer.modInstallFail"), e);
+        } catch (Exception x) {
+            log.error(sm.getString("farmWarDeployer.modInstallFail"), x);
         }
     }
 
+    /**
+     * War remove from watchDir
+     *
+     * @see org.apache.catalina.ha.deploy.FileChangeListener#fileRemoved(File)
+     */
     @Override
     public void fileRemoved(File removeWar) {
         try {
@@ -441,8 +456,8 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
                 log.info(sm.getString("farmWarDeployer.removeLocal", cn.getName()));
             }
             remove(cn.getName(), true);
-        } catch (Exception e) {
-            log.error(sm.getString("farmWarDeployer.removeLocalFail"), e);
+        } catch (Exception x) {
+            log.error(sm.getString("farmWarDeployer.removeLocalFail"), x);
         }
     }
 
@@ -487,7 +502,7 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
      */
     protected void undeployDir(File dir) {
 
-        String[] files = dir.list();
+        String files[] = dir.list();
         if (files == null) {
             files = new String[0];
         }
@@ -540,41 +555,6 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
         mBeanServer.invoke(oname, "check", params, signature);
     }
 
-    /**
-     * Verified if a context is being services.
-     *
-     * @param name The context name
-     *
-     * @return <code>true</code> if the context is being serviced
-     *
-     * @throws Exception Error invoking the deployer
-     *
-     * @deprecated Unused. Will be removed in Tomcat 10.1.x onwards.
-     */
-    @Deprecated
-    protected boolean isServiced(String name) throws Exception {
-        String[] params = { name };
-        String[] signature = { "java.lang.String" };
-        Boolean result = (Boolean) mBeanServer.invoke(oname, "isServiced", params, signature);
-        return result.booleanValue();
-    }
-
-    /**
-     * Mark a context as being services.
-     *
-     * @param name The context name
-     *
-     * @throws Exception Error invoking the deployer
-     *
-     * @deprecated Unused. Will be removed in Tomcat 10.1.x onwards. Use {@link #tryAddServiced}
-     */
-    @Deprecated
-    protected void addServiced(String name) throws Exception {
-        String[] params = { name };
-        String[] signature = { "java.lang.String" };
-        mBeanServer.invoke(oname, "addServiced", params, signature);
-    }
-
     /**
      * Attempt to mark a context as being serviced
      *
@@ -606,6 +586,16 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
     }
 
     /*--Instance Getters/Setters--------------------------------*/
+    @Override
+    public boolean equals(Object listener) {
+        return super.equals(listener);
+    }
+
+    @Override
+    public int hashCode() {
+        return super.hashCode();
+    }
+
     public String getDeployDir() {
         return deployDir;
     }
@@ -716,8 +706,8 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
                     return false;
                 }
             }
-        } catch (IOException ioe) {
-            log.error(sm.getString("farmWarDeployer.fileCopyFail", from, to), ioe);
+        } catch (IOException e) {
+            log.error(sm.getString("farmWarDeployer.fileCopyFail", from, to), e);
             return false;
         }
 
@@ -731,8 +721,8 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
                 }
                 os.write(buf, 0, len);
             }
-        } catch (IOException ioe) {
-            log.error(sm.getString("farmWarDeployer.fileCopyFail", from, to), ioe);
+        } catch (IOException e) {
+            log.error(sm.getString("farmWarDeployer.fileCopyFail", from, to), e);
             return false;
         }
         return true;
@@ -755,8 +745,7 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
         }
         try {
             dir = dir.getCanonicalFile();
-        } catch (IOException ignore) {
-            // Ignore
+        } catch (IOException e) {// ignore
         }
         return dir;
     }
